@@ -41,7 +41,7 @@ def get_open_fn(infile: Union[str, Path]):
         return open
 
 
-def fix_encoding(fpath: Union[str, Path], backup_file: bool = True) -> bool:
+def fix_encoding(fpath: Union[str, Path], backup_file: bool = True) -> Union[str, bool]:
     """Try to decode the context of the file as text in UTF-8, if it fails, try windows encoding before try to detect
     encoding of the file.
 
